package WebGUI::i18n::Dutch::Asset_Event;
use utf8;
our $I18N = {
  'After' => {
    'lastUpdated' => '1257328531',
    'message' => 'Na'
  },
  'By date' => {
    'lastUpdated' => '1257328537',
    'message' => 'Op datum'
  },
  'Daily' => {
    'lastUpdated' => '1257328544',
    'message' => 'Dagelijks'
  },
  'Every' => {
    'lastUpdated' => '1257328549',
    'message' => 'Elke'
  },
  'Every N months on' => {
    'lastUpdated' => '1257328561',
    'message' => 'Elke %s maanden op'
  },
  'Every N weeks on' => {
    'lastUpdated' => '1257328571',
    'message' => 'Elke %s weken op'
  },
  'Every N years on' => {
    'lastUpdated' => '1257328584',
    'message' => 'Elke %s jaar op'
  },
  'Monthly' => {
    'lastUpdated' => '1257328591',
    'message' => 'Maandelijks'
  },
  'No end' => {
    'lastUpdated' => '1257328600',
    'message' => 'Geen einde'
  },
  'No specific time' => {
    'lastUpdated' => '1257328616',
    'message' => 'Geen specifieke tijd (hele dag)'
  },
  'Specific start/end time' => {
    'lastUpdated' => '1257328645',
    'message' => 'Specifieke begin -en eindtijd'
  },
  'The event end date must be after the event start date.' => {
    'lastUpdated' => '1246969482',
    'message' => 'De einddatum van het evenement moet na de begindatum vallen.'
  },
  'The event end time must be after the event start time.' => {
    'lastUpdated' => '1246969437',
    'message' => 'De eindtijd van het evenement moet na de starttijd vallen.'
  },
  'UserDefinedN' => {
    'lastUpdated' => '1207837642',
    'message' => 'De waarde van dit veld. Er zijn vijf &quot;UserDefined&quot; velden, UserDefined1 tot en met UserDefined5, waarin willekeurige gegevens gestopt kunnen worden. '
  },
  'Weekday(s)' => {
    'lastUpdated' => '1257328652',
    'message' => 'Weekdagen'
  },
  'Weekly' => {
    'lastUpdated' => '1257328658',
    'message' => 'Wekelijks'
  },
  'Yearly' => {
    'lastUpdated' => '1257328664',
    'message' => 'Jaarlijks'
  },
  'add related link' => {
    'lastUpdated' => '1205852766',
    'message' => 'Voeg een nieuw gerelateerde link toe'
  },
  'add/edit title' => {
    'lastUpdated' => '1166194025',
    'message' => 'Gebeurtenis, Toevoegen/Wijzigen'
  },
  'assetName' => {
    'lastUpdated' => '1153759908',
    'message' => 'Gebeurtenis'
  },
  'attachment.icon' => {
    'lastUpdated' => '1190027722',
    'message' => 'Een icoon die het bestandstype aangeeft van de bijlage.'
  },
  'attachment.name' => {
    'lastUpdated' => '1190027709',
    'message' => 'De naam van de eerste bijlage bij deze bijdrage.'
  },
  'attachment.url' => {
    'lastUpdated' => '1207837440',
    'message' => 'De URL om de eerste bijlage bij deze bijdrage te downloaden.'
  },
  'attachment_loop' => {
    'lastUpdated' => '1190027668',
    'message' => 'Een loop waarin alle bestanden en afbeeldingen beschikbaar zijn die horen bij deze bijdrage.'
  },
  'attachment_url' => {
    'lastUpdated' => '1190027646',
    'message' => 'De URL om de bijlage te downloaden.'
  },
  'attachments' => {
    'lastUpdated' => '1205852775',
    'message' => 'Bijlagen'
  },
  'attachments for event' => {
    'lastUpdated' => '1205852787',
    'message' => 'Bijlagen voor dit evenement'
  },
  'canEdit' => {
    'lastUpdated' => '1190027634',
    'message' => 'Deze variabele waarde is waar als de huidige gebruiker deze gebeurtenis kan bewerken.'
  },
  'dateSpan' => {
    'lastUpdated' => '1189336080',
    'message' => 'Een vriendelijke weergave van de start- en einddata en tijden van deze gebeurtenis.'
  },
  'day' => {
    'lastUpdated' => '1257328671',
    'message' => 'dag'
  },
  'delete' => {
    'lastUpdated' => '1205852796',
    'message' => 'Verwijderen'
  },
  'description' => {
    'lastUpdated' => '1205852812',
    'message' => 'Omschrijving'
  },
  'description label' => {
    'lastUpdated' => '1216585930',
    'message' => 'Beschrijving'
  },
  'edit' => {
    'lastUpdated' => '1205852819',
    'message' => 'Bewerken'
  },
  'end' => {
    'lastUpdated' => '1205852825',
    'message' => 'Einde'
  },
  'end date' => {
    'lastUpdated' => '1205852833',
    'message' => 'Einddatum'
  },
  'endDate' => {
    'lastUpdated' => '1189336147',
    'message' => 'De datum waarop deze gebeurtenis eindigt.'
  },
  'endDateDayAbbr' => {
    'lastUpdated' => '1189336141',
    'message' => 'De afkorting van de naam van de dag waarop deze gebeurtenis eindigt.'
  },
  'endDateDayName' => {
    'lastUpdated' => '1189336164',
    'message' => 'De naam van de dag waarop de gebeurtenis eindigt.'
  },
  'endDateDayOfMonth' => {
    'lastUpdated' => '1189336188',
    'message' => 'De dag van de maand waarop deze gebeurtenis eindigt. Dit is een nummer van 1 tot en met 31.'
  },
  'endDateDayOfWeek' => {
    'lastUpdated' => '1189336215',
    'message' => 'De dag van de week waarin deze gebeurtenis eindigt. Dit is een nummer van 1 tot en met 7.'
  },
  'endDateDmy' => {
    'lastUpdated' => '1189336255',
    'message' => 'De einddatum van deze gebeurtenis, in het formaat dd-mm-yyyy. Hierbij is yyyy het jaar, mm de maand en dd de dag.'
  },
  'endDateEpoch' => {
    'lastUpdated' => '1189336355',
    'message' => 'De einddatum van deze gebeurtenis in epoch formaat. (Dat is het aantal seconden sinds 1 januari 1970 Zulu-tijd.)'
  },
  'endDateHms' => {
    'lastUpdated' => '1189336392',
    'message' => 'De eindtijd van deze gebeurtenis in hh.mm.ss formaat, waarbij hh het uur is, mm de minuut en ss de seconde.'
  },
  'endDateHour' => {
    'lastUpdated' => '1189336406',
    'message' => 'Het uur waarin deze gebeurtenis eindigt.'
  },
  'endDateHour24' => {
    'lastUpdated' => '1189336427',
    'message' => 'Het uur, van een 24 uurs klok, waarin deze gebeurtenis eindigt.'
  },
  'endDateHourM' => {
    'lastUpdated' => '1189336482',
    'message' => 'De tekst "am" of "pm" wanneer de gebeurtenis in respectievelijk de ochtend of de middag plaatsvindt. '
  },
  'endDateMdy' => {
    'lastUpdated' => '1189336513',
    'message' => 'De einddatum van deze gebeurtenis, in het mm-dd-yyyy formaat. Hierbij is yyyy het jaar, mm de maand en dd de dag.'
  },
  'endDateMinute' => {
    'lastUpdated' => '1189336557',
    'message' => 'De minuut, weergegeven met twee cijfers, waarin deze gebeurtenis eindigt.'
  },
  'endDateMonthAbbr' => {
    'lastUpdated' => '1189336571',
    'message' => 'De afkorting van de naam van de maand waarin deze gebeurtenis eindigt.'
  },
  'endDateMonthName' => {
    'lastUpdated' => '1189336585',
    'message' => 'De naam van de maand waarin deze gebeurtenis eindigt.'
  },
  'endDateSecond' => {
    'lastUpdated' => '1189336606',
    'message' => 'De seconde, weergegeven met twee cijfers, waarin deze gebeurtenis eindigt.'
  },
  'endDateYear' => {
    'lastUpdated' => '1189336623',
    'message' => 'Het jaar waarin deze gebeurtenis eindigt in vier cijfers.'
  },
  'endDateYmd' => {
    'lastUpdated' => '1189336667',
    'message' => 'Het jaar waarin deze gebeurtenis eindigt in yyyy-mm-dd formaat. Hierbij is yyyy het jaar, mm de maand en dd de dag.'
  },
  'endTime' => {
    'lastUpdated' => '1207838828',
    'message' => 'De tijd waarop deze gebeurtenis eindigt.'
  },
  'errors' => {
    'lastUpdated' => '1205852841',
    'message' => 'Fouten!'
  },
  'event asset template variables body' => {
    'lastUpdated' => '1189336743',
    'message' => 'Elk object maakt een aantal variabelen beschikbaar aan de meeste van zijn templates gebaseerd op interne kenmerken van het object. Deze variabelen zijn niet allemaal even bruikbaar.'
  },
  'event asset template variables title' => {
    'lastUpdated' => '1189336810',
    'message' => 'Gebeurtenis object template variabelen'
  },
  'event common template variables body' => {
    'lastUpdated' => '1189336840',
    'message' => 'Deze template variabelen worden gebruikt in zowel de gebeurtenis als de kalender.'
  },
  'event common template variables title' => {
    'lastUpdated' => '1189336857',
    'message' => 'Gebeurtenis overeenkomstige template variabelen.'
  },
  'event details' => {
    'lastUpdated' => '1205852851',
    'message' => 'Details evenement'
  },
  'event title' => {
    'lastUpdated' => '1205852860',
    'message' => 'Titel evenement'
  },
  'event view template variables body' => {
    'lastUpdated' => '1189336886',
    'message' => 'Deze template variabelen worden gebruik in het template dat de gebeurtenis laat zien aan de gebruikers.'
  },
  'event view template variables title' => {
    'lastUpdated' => '1189336902',
    'message' => 'Gebeurtenis weergave template variabelen.'
  },
  'exclude dates' => {
    'lastUpdated' => '1205852876',
    'message' => 'Sluit data uit'
  },
  'feedId' => {
    'lastUpdated' => '1189336934',
    'message' => 'Een unieke identificatie voor de iCal feed.'
  },
  'feedUid' => {
    'lastUpdated' => '1189336964',
    'message' => 'De locatie van deze gebeurtenis.'
  },
  'filename' => {
    'lastUpdated' => '1190027612',
    'message' => 'De naam van deze bijlage.'
  },
  'first' => {
    'lastUpdated' => '1257328676',
    'message' => 'eerste'
  },
  'formAttachments' => {
    'lastUpdated' => '1190027605',
    'message' => 'HTML formulier om bestanden bij te voegen of te verwijderen bij deze gebeurtenis.'
  },
  'formCancel' => {
    'lastUpdated' => '1189336986',
    'message' => 'De HTML button om het toevoegen of wijzigen van een gebeurtenis af te breken.'
  },
  'formDescription' => {
    'lastUpdated' => '1189337015',
    'message' => 'Een HTML formulier om beschrijvingen van gebeurtenissen toe te voegen of te wijzigen.'
  },
  'formEndDate' => {
    'lastUpdated' => '1189337046',
    'message' => 'Een HTML formulier om de einddatum van een gebeurtenis toe te voegen of te wijzigen.'
  },
  'formEndTime' => {
    'lastUpdated' => '1189337066',
    'message' => 'HTML formulier om de eindtijd van een gebeurtenis toe te voegen of te wijzigen.'
  },
  'formErrors' => {
    'lastUpdated' => '1189337145',
    'message' => 'Deze loop bevat fouten die mogelijk voorgekomen zijn bij het verwerken van de gegevens uit het formulier waarmee de gebeurtenis is toegevoegd of gewijzigd.'
  },
  'formFooter' => {
    'lastUpdated' => '1189337168',
    'message' => 'De HTML voor het einde van het formulier waarmee een gebeurtenis wordt toegevoegd of gewijzigd.'
  },
  'formGroupToView' => {
    'lastUpdated' => '1208520378',
    'message' => 'HTML formulier waarmee de groep gekozen kan worden die dit evenement mag zien. '
  },
  'formHeader' => {
    'lastUpdated' => '1189337200',
    'message' => 'De HTML of het Javascript voor het begin van een formulier om een gebeurtenis toe te voegen of te wijzigen.'
  },
  'formLocation' => {
    'lastUpdated' => '1189337229',
    'message' => 'De HTML om de locatie van een gebeurtenis in te voeren of te wijzigen.'
  },
  'formMenuTitle' => {
    'lastUpdated' => '1189337318',
    'message' => 'Deze variabele geeft het stukje HTML weer waarmee de menu-titel van de gebeurtenis kan worden toegevoegd of gewijzigd. '
  },
  'formRecurEnd' => {
    'lastUpdated' => '1189337418',
    'message' => 'Het HTML datumformulier waarmee kan worden aangegeven wanneer een terugkerende gebeurtenis eindigt, wanneer deze ooit eindigt.'
  },
  'formRecurPattern' => {
    'lastUpdated' => '1189337447',
    'message' => 'HTML en javascript voor een formulier dat weergeeft hoe een gebeurtenis zich herhaalt.'
  },
  'formRecurStart' => {
    'lastUpdated' => '1189337491',
    'message' => 'HTML datumformulier om de eerste datum waarop een gebeurtenis herhaalt in te geven.'
  },
  'formRelatedLinks' => {
    'lastUpdated' => '1189337567',
    'message' => 'Een HTML text-element om de URL\'s voor de websites met meer informatie over de gebeurtenis in te geven. Per regel kan een link worden gegeven.'
  },
  'formSave' => {
    'lastUpdated' => '1189337614',
    'message' => 'De HTML om een bewaar-button weer te geven om de gegevens van de gebeurtenis te bewaren.'
  },
  'formStartDate' => {
    'lastUpdated' => '1189337656',
    'message' => 'Het HTML formulier-element om de startdatum van een gebeurtenis in te geven of te wijzigen. '
  },
  'formStartTime' => {
    'lastUpdated' => '1189337691',
    'message' => 'Het HTML formulier element waarmee de startdatum van de gebeurtenis kan worden ingegeven of gewijzigd.'
  },
  'formSynopsis' => {
    'lastUpdated' => '1257328705',
    'message' => 'HTML formulier voor het bewerken van de samenvatting van het evenement.'
  },
  'formTime' => {
    'lastUpdated' => '1207837716',
    'message' => 'Het HTML formulier element waarmee de start- en eindtijden van de gebeurtenis gewijzigd kunnen worden. Het heeft snelkeuze mogelijkheden voor &quot;de gehele dag&quot;, &quot;geen specifieke tijd&quot;, en een specifieke start- en eindtijd.'
  },
  'formTitle' => {
    'lastUpdated' => '1189337810',
    'message' => 'Het HTML formulier-element waarmee de titel van de gebeurtenis kan worden ingevoerd of gewijzigd.'
  },
  'formUserDefinedN' => {
    'lastUpdated' => '1207838483',
    'message' => 'Dit is een formulier met een enkele tekstregel voor elk van de 5 Gebruiker Gedefinieerde velden'
  },
  'formUserDefinedN_float' => {
    'lastUpdated' => '1207838498',
    'message' => 'Voor elk van de vijf door Gebruiker Gedefinieerde velden, een formulier functie voor een float.'
  },
  'formUserDefinedN_htmlarea' => {
    'lastUpdated' => '1199700085',
    'message' => 'Een formulier functie voor een HTML WYSIWIG veld in elk van de vijf door Gebruiker Gedefinieerde velden.'
  },
  'formUserDefinedN_textarea' => {
    'lastUpdated' => '1199700143',
    'message' => 'Een tekst gebied formulier onderdeel, voor elk van de vijf door een Gebruiker Gedefineerde velden.'
  },
  'formUserDefinedN_yesNo' => {
    'lastUpdated' => '1199700220',
    'message' => 'Een ja/nee veld voor elk van de vijf door een Gebruiker Gedefinieerde velden.'
  },
  'fourth' => {
    'lastUpdated' => '1257328711',
    'message' => 'vierde'
  },
  'group to view' => {
    'lastUpdated' => '1205852896',
    'message' => 'Groep om dit evenement te bezichtigen'
  },
  'groupToView' => {
    'lastUpdated' => '1189337828',
    'message' => 'De ID van de groep die de gebeurtenis mag bekijken.'
  },
  'icon' => {
    'lastUpdated' => '1190027554',
    'message' => 'Een icoon die het bestandstype aangeeft voor deze bijlage.'
  },
  'image.thumbnail' => {
    'lastUpdated' => '1190027536',
    'message' => 'Een thumbnail van de afbeelding die is bijgevoegd bij het bericht.'
  },
  'image.url' => {
    'lastUpdated' => '1190027519',
    'message' => 'De URL naar de eerste afbeelding die is bijgevoegd bij de bijdrage.'
  },
  'include dates' => {
    'lastUpdated' => '1205853234',
    'message' => 'Voeg data toe'
  },
  'invalid end date' => {
    'lastUpdated' => '1297774511',
    'message' => 'Ongeldige einddatum. Voer alstublieft een geldige datum in in de vorm "JJJJ-MM-DD".'
  },
  'invalid start date' => {
    'lastUpdated' => '1297774526',
    'message' => 'Ongeldige begindatum. Voer alstublieft een geldige datum in in de vorm "JJJJ-MM-DD".'
  },
  'isAllDay' => {
    'lastUpdated' => '1189337850',
    'message' => 'Een voorwaardelijke variabele die waar is wanneer de gebeurtenis de gehele dag duurt. '
  },
  'isImage' => {
    'lastUpdated' => '1190027493',
    'message' => 'Een voorwaardelijke variabele die aangeeft of de bijlage een afbeelding is of niet.'
  },
  'isOneDay' => {
    'lastUpdated' => '1189337886',
    'message' => 'Een voorwaardelijke variabele die waar is wanneer de gebeurtenis op dezelfde dag start en eindigt. '
  },
  'isPublic' => {
    'lastUpdated' => '1189337932',
    'message' => 'Een voorwaardelijke variabele die waar is als de gebeurtenis door iedereen mag worden gezien. (De groep die de gebeurtenis mag bekijken is "Everyone".)'
  },
  'last' => {
    'lastUpdated' => '1257328716',
    'message' => 'laatste'
  },
  'link description' => {
    'lastUpdated' => '1205852918',
    'message' => 'Link omschrijving'
  },
  'link view group' => {
    'lastUpdated' => '1205852936',
    'message' => 'Bezichtig groep'
  },
  'linkUrl' => {
    'lastUpdated' => '1189337959',
    'message' => 'Een URL van uit de set van gerelateerde links.'
  },
  'locale' => {
    'lastUpdated' => '1166194041',
    'message' => 'nl_NL'
  },
  'location' => {
    'lastUpdated' => '1205852946',
    'message' => 'Locatie'
  },
  'message' => {
    'lastUpdated' => '1189337980',
    'message' => 'Een foutmelding.'
  },
  'next event' => {
    'lastUpdated' => '1205852973',
    'message' => 'Volgende evenement'
  },
  'nextUrl' => {
    'lastUpdated' => '1189338014',
    'message' => 'De URL naar de eerstvolgende gebeurtenis in de kalender. '
  },
  'occurences' => {
    'lastUpdated' => '1257329177',
    'message' => 'keren'
  },
  'of' => {
    'lastUpdated' => '1257329082',
    'message' => 'van'
  },
  'prevUrl' => {
    'lastUpdated' => '1189338046',
    'message' => 'Een URL naar de vorige gebeurtenis in de kalender. Vorige in chronologische zin.'
  },
  'previous event' => {
    'lastUpdated' => '1205852984',
    'message' => 'Vorige evenement'
  },
  'print' => {
    'lastUpdated' => '1205852994',
    'message' => 'Afdrukken'
  },
  'recurId' => {
    'lastUpdated' => '1189338086',
    'message' => 'De unieke identificatie van de herhalingsgegevens van deze gebeurtenis in de database.'
  },
  'recurrence' => {
    'lastUpdated' => '1205853004',
    'message' => 'Herhaling'
  },
  'recurrence pattern' => {
    'lastUpdated' => '1205853016',
    'message' => 'Herhalingspatroon'
  },
  'recurrence range' => {
    'lastUpdated' => '1205853032',
    'message' => 'Herhalingsbereik'
  },
  'related material' => {
    'lastUpdated' => '1205853066',
    'message' => 'Verwant materiaal'
  },
  'relatedLinks' => {
    'lastUpdated' => '1189338124',
    'message' => 'In deze loop zijn alle links beschikbaar uit de verzameling relevante links van deze gebeurtenis.'
  },
  'relatedLinks assetVar' => {
    'lastUpdated' => '1189338180',
    'message' => 'De orginele, onverwerkte, relevante links uit het formulier. Dit zijn alle links als tekst, samengevoegd met enters.'
  },
  'scheduled' => {
    'lastUpdated' => '1208520597',
    'message' => 'Ingepland'
  },
  'second' => {
    'lastUpdated' => '1257329088',
    'message' => 'tweede'
  },
  'short title' => {
    'lastUpdated' => '1205853119',
    'message' => 'Korte titel'
  },
  'start' => {
    'lastUpdated' => '1205853126',
    'message' => 'Start'
  },
  'start date' => {
    'lastUpdated' => '1205853135',
    'message' => 'Startdatum'
  },
  'startDate' => {
    'lastUpdated' => '1189338192',
    'message' => 'De datum waarop deze gebeurtenis start.'
  },
  'startDateDayAbbr' => {
    'lastUpdated' => '1189338209',
    'message' => 'De afkorting van de naam van de dag waarop deze gebeurtenis start.'
  },
  'startDateDayName' => {
    'lastUpdated' => '1189338227',
    'message' => 'De naam van de dag waarop de gebeurtenis start.'
  },
  'startDateDayOfMonth' => {
    'lastUpdated' => '1189338249',
    'message' => 'De dag van de maand waarin deze gebeurtenis start. Dit is een nummer van 1 tot en met 31.'
  },
  'startDateDayOfWeek' => {
    'lastUpdated' => '1189338274',
    'message' => 'De dag van de week waarin deze gebeurtenis start. Dit is een nummer van 1 tot en met 7.'
  },
  'startDateDmy' => {
    'lastUpdated' => '1189338305',
    'message' => 'De startdatum van deze gebeurtenis in het formaat dd-mm-yyyy. Hierbij is yyyy het jaar, mm de maand en dd de dag.'
  },
  'startDateEpoch' => {
    'lastUpdated' => '1189338348',
    'message' => 'De startdatum van de gebeurtenis in epoch formaat. (Dit is het aantal seconden sinds 1 januari 1970 Zulu-tijd. Dit wordt ook wel Unix-timestamp genoemd.)'
  },
  'startDateHms' => {
    'lastUpdated' => '1189338379',
    'message' => 'De starttijd voor deze gebeurtenis, in het formaat hh:mm:ss. Hierbij is hh het uur, mm de minuut en ss de seconde.'
  },
  'startDateHour' => {
    'lastUpdated' => '1189338392',
    'message' => 'Het uur waarop deze gebeurtenis start.'
  },
  'startDateHour24' => {
    'lastUpdated' => '1189338410',
    'message' => 'Het uur, op een 24 uurs klok, waarop deze gebeurtenis start.'
  },
  'startDateHourM' => {
    'lastUpdated' => '1189338451',
    'message' => 'Afhankeljik van of de gebeurtenis plaatsvindt in de morgen of de middag, bevat deze variabele de tekst "am" of "pm".'
  },
  'startDateMdy' => {
    'lastUpdated' => '1189347737',
    'message' => 'De startdatum van deze gebeurtenis in mm-dd-yyyy formaat. Hierbij is mm de maand, dd de dag en yyyy het jaar.'
  },
  'startDateMinute' => {
    'lastUpdated' => '1189347758',
    'message' => 'De minuut, weergegeven met twee cijfers, waarmee deze gebeurtenis start.'
  },
  'startDateMonthAbbr' => {
    'lastUpdated' => '1189347787',
    'message' => 'De afkorting van de naam van maand waarin deze gebeurtenis start.'
  },
  'startDateMonthName' => {
    'lastUpdated' => '1207837369',
    'message' => 'De naam van de maand waarin deze gebeurtenis start.'
  },
  'startDateSecond' => {
    'lastUpdated' => '1189347830',
    'message' => 'De seconde, weergegeven met twee cijfers, waarmee deze gebeurtenis start.'
  },
  'startDateYear' => {
    'lastUpdated' => '1189347848',
    'message' => 'Het jaar waarin deze gebeurtenis start, weergegeven met vier cijfers.'
  },
  'startDateYmd' => {
    'lastUpdated' => '1189347882',
    'message' => 'De startdatum van deze gebeurtenis, in yyyy-mm-dd formaat. Waarbij yyyy het jaar is, mm de maand en dd de dag.'
  },
  'startTime' => {
    'lastUpdated' => '1207838785',
    'message' => 'De tijd waarop deze gebeurtenis start'
  },
  'tab event' => {
    'lastUpdated' => '1205853142',
    'message' => 'Evenement'
  },
  'third' => {
    'lastUpdated' => '1257329095',
    'message' => 'derde'
  },
  'thumbnail' => {
    'lastUpdated' => '1190027477',
    'message' => 'Een thumbnail van deze bijlage, indien van toepassing.'
  },
  'time' => {
    'lastUpdated' => '1205853150',
    'message' => 'Tijd'
  },
  'url' => {
    'lastUpdated' => '1189347908',
    'message' => 'De URL voor deze gebeurtenis.'
  },
  'urlDay' => {
    'lastUpdated' => '1208520775',
    'message' => 'De URL om alle gebeurtenissen op een dag weer te geven in deze kalender.'
  },
  'urlDelete' => {
    'lastUpdated' => '1242725777',
    'message' => 'Een URL om de gebeurtenis te verwijderen'
  },
  'urlEdit' => {
    'lastUpdated' => '1242725799',
    'message' => 'Een URL om de gebeurtenis te wijzigen'
  },
  'urlList' => {
    'lastUpdated' => '1242725833',
    'message' => 'Een URL om de gebeurtenisen te tonen in een lijst in plaats van in een kalendar'
  },
  'urlMonth' => {
    'lastUpdated' => '1189347975',
    'message' => 'De URL om de gebeurtenissen in dezelfde maand weer te geven in deze kalender'
  },
  'urlParent' => {
    'lastUpdated' => '1242725929',
    'message' => 'De URL om de kalender weer te geven waartoe deze gebeurtenis behoort.'
  },
  'urlPrint' => {
    'lastUpdated' => '1242725909',
    'message' => 'Een URL om deze gebeurtenis te tonen in een sjabloon dat geoptimaliseerd is voor afdrukken op een printer'
  },
  'urlSearch' => {
    'lastUpdated' => '1189348038',
    'message' => 'De URL om het zoekfunctie weer te geven van de kalender waartoe deze gebeurtenis behoort.'
  },
  'urlWeek' => {
    'lastUpdated' => '1189348052',
    'message' => 'De URL om alle gebeurtenissen in dezelfde week weer te geven. '
  },
  'week on' => {
    'lastUpdated' => '1257329112',
    'message' => 'week op'
  }
}
;

1;
